@@ -259,14 +259,12 @@ struct _MetaColorSpec
       MetaColorSpec *background;
       double alpha;
 
-      gboolean color_set;
       GdkColor color;
     } blend;
     struct {
       MetaColorSpec *base;
       double factor;
 
-      gboolean color_set;
       GdkColor color;
     } shade;
   } data;
@@ -807,8 +805,6 @@ struct _MetaTheme
   GHashTable *style_sets_by_name;
   MetaFrameStyleSet *style_sets_by_type[META_FRAME_TYPE_LAST];
 
-  GdkPixbuf *fallback_icon, *fallback_mini_icon;
-
   GQuark quark_width;
   GQuark quark_height;
   GQuark quark_object_width;
